import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_platform_authentication_ui/senior_platform_authentication_ui.dart';

import 'biometric_settings.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({super.key});

  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  User? user;
  Token? token;
  ApplicationKey? applicationKey;
  Token? keyToken;

  @override
  void initState() {
    super.initState();
  }

  Future<void> _syncData() async {
    const username = UserName();
    user = await GetStoredUserUsecase().call(username);
    token = await GetStoredTokenUsecase().call(username);
    applicationKey = await GetStoredKeyUsecase().call(null);
    keyToken = await GetStoredKeyTokenUsecase().call(null);
    await Future.delayed(const Duration(seconds: 1));
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: _syncData(),
      builder: (context, snapshot) {
        if (snapshot.connectionState != ConnectionState.done) {
          return Scaffold(
            appBar: AppBar(
              title: const Text('Carregando'),
            ),
            body: const Center(
              child: CircularProgressIndicator(
                color: Colors.deepPurpleAccent,
              ),
            ),
          );
        } else {
          if (SeniorAuthentication.enableLoginWithKey) {
            return Scaffold(
              appBar: AppBar(
                title: const Text('Bem vindo'),
              ),
              body: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  const Center(child: Text('Home Screen')),
                  const SizedBox(height: 16),
                  const Text('Authenticated Key'),
                  Text(applicationKey!.accessKey),
                  const SizedBox(height: 16),
                  Text('Domain: ${applicationKey?.tenantName}'),
                  const SizedBox(height: 16),
                  const Text('Current accessToken:'),
                  Text(keyToken!.accessToken),
                  const SizedBox(height: 16),
                  ElevatedButton(
                    child: const Text('logout'),
                    onPressed: () async {
                      context
                          .read<AuthenticationBloc>()
                          .add(const LogoutOnlineRequested());
                    },
                  ),
                  const SizedBox(height: 16),
                ],
              ),
            );
          } else {
            return Scaffold(
              appBar: AppBar(
                title: Text('Bem vindo ${user?.fullName}'),
              ),
              body: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  const Center(child: Text('Home Screen')),
                  const SizedBox(height: 16),
                  Text('Current accessToken: ${token?.accessToken}'),
                  const SizedBox(height: 16),
                  ElevatedButton(
                    child: const Text('logout'),
                    onPressed: () async {
                      final username =
                          AuthenticationBloc().state.username ?? '';
                      context
                          .read<AuthenticationBloc>()
                          .add(LogoutOfflineRequested(username: username));
                    },
                  ),
                  ElevatedButton(
                    child: const Text('Configurar Biometria'),
                    onPressed: () async {
                      Navigator.push<void>(
                        context,
                        MaterialPageRoute<void>(
                          builder: (_) => const BiometricSettings(),
                        ),
                      );
                    },
                  ),
                ],
              ),
            );
          }
        }
      },
    );
  }
}
