import 'dart:developer';

import '../../../../../senior_platform_authentication_ui.dart';

import '../../data/repositories/secure_storage_repository.dart';

/// Get current token on local storage.
///
/// This usecase does not syncronize the token local data with remote data.
/// Use it to get the token that is saved on local storage.
class GetStoredTokenUsecase implements BaseUsecase<Token?, UserName> {
  late final SecureStorageRepository _secureStorageRepository;
  late final ClearStoredDataUsecase _clearStoredDataUsecase;

  GetStoredTokenUsecase({
    SecureStorageRepository? secureStorageRepository,
    ClearStoredDataUsecase? clearStoredDataUsecase,
  }) {
    _secureStorageRepository =
        secureStorageRepository ?? SecureStorageRepositoryImpl();
    _clearStoredDataUsecase =
        clearStoredDataUsecase ?? ClearStoredDataUsecase();
  }

  @override
  Future<Token?> call(UserName username) async {
    try {
      final currentUsername = username.currentUsername?.isEmpty ?? true
          ? await _secureStorageRepository.readLastUser() ?? ''
          : username.currentUsername!;

      return await _secureStorageRepository.readToken(
          username: currentUsername);
    } catch (e) {
      log('GET STORED TOKEN ERROR >>>> ${e.toString()}');
      try {
        await _clearStoredDataUsecase(username);
      } catch (e) {
        return null;
      }
      return null;
    }
  }
}
