part of 'authentication_bloc.dart';

class AuthenticationState extends Equatable {
  /// Current key authentication status
  ///
  /// Default value is [AuthenticationStatus.unknown] when app is initializing.
  final AuthenticationStatus accessKeyStatus;

  /// Current accessKey saved on memory.
  final String? accessKey;

  /// Current authentication status
  ///
  /// Default value is [AuthenticationStatus.unknown] when app is initializing.
  final AuthenticationStatus status;

  /// Current username saved on memory.
  final String? username;

  final BiometryStatus biometryStatus;

  const AuthenticationState._({
    this.status = AuthenticationStatus.unknown,
    this.username,
    this.accessKeyStatus = AuthenticationStatus.unknown,
    this.accessKey,
    this.biometryStatus = BiometryStatus.unknown,
  });

  /// Unkown authentication state.
  ///
  /// It means that the application doesn't know yet the status of authentication.
  const AuthenticationState.unknown() : this._();

  const AuthenticationState.keyAuthenticated({String? accessKey})
      : this._(
          accessKeyStatus: AuthenticationStatus.authenticated,
          accessKey: accessKey,
        );

  const AuthenticationState.keyUnauthenticated()
      : this._(
          accessKeyStatus: AuthenticationStatus.unauthenticated,
          accessKey: null,
        );

  const AuthenticationState.keyOffline(String accessKey)
      : this._(
          accessKeyStatus: AuthenticationStatus.offline,
          accessKey: accessKey,
        );

  /// Authenticated authentication state.
  ///
  /// The state that is emitted when the authentication status changed to
  /// authenticated.
  const AuthenticationState.authenticated(
      {String? username,
      BiometryStatus biometryStatus = BiometryStatus.unknown})
      : this._(
          status: AuthenticationStatus.authenticated,
          username: username,
          biometryStatus: BiometryStatus.unknown,
        );

  /// Unauthenticated authentication state.
  ///
  /// The state that is emitted when the authentication status changed to
  /// unauthenticated.
  const AuthenticationState.unauthenticated(
      {BiometryStatus biometryStatus = BiometryStatus.unknown})
      : this._(
          status: AuthenticationStatus.unauthenticated,
          username: null,
          biometryStatus: biometryStatus,
        );

  /// Offline authentication state.
  ///
  /// The state that is emitted when the connection to network is lost.
  const AuthenticationState.offline(String username)
      : this._(
          status: AuthenticationStatus.offline,
          username: username,
        );

  @override
  List<Object?> get props => [
        accessKeyStatus,
        accessKey,
        status,
        username,
      ];
}
