import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:intl/intl.dart' as intl;

import 'app_localizations_en.dart';
import 'app_localizations_es.dart';
import 'app_localizations_pt.dart';

/// Callers can lookup localized strings with an instance of AppLocalizations
/// returned by `AppLocalizations.of(context)`.
///
/// Applications need to include `AppLocalizations.delegate()` in their app's
/// `localizationDelegates` list, and the locales they support in the app's
/// `supportedLocales` list. For example:
///
/// ```dart
/// import 'gen/app_localizations.dart';
///
/// return MaterialApp(
///   localizationsDelegates: AppLocalizations.localizationsDelegates,
///   supportedLocales: AppLocalizations.supportedLocales,
///   home: MyApplicationHome(),
/// );
/// ```
///
/// ## Update pubspec.yaml
///
/// Please make sure to update your pubspec.yaml to include the following
/// packages:
///
/// ```yaml
/// dependencies:
///   # Internationalization support.
///   flutter_localizations:
///     sdk: flutter
///   intl: any # Use the pinned version from flutter_localizations
///
///   # Rest of dependencies
/// ```
///
/// ## iOS Applications
///
/// iOS applications define key application metadata, including supported
/// locales, in an Info.plist file that is built into the application bundle.
/// To configure the locales supported by your app, you’ll need to edit this
/// file.
///
/// First, open your project’s ios/Runner.xcworkspace Xcode workspace file.
/// Then, in the Project Navigator, open the Info.plist file under the Runner
/// project’s Runner folder.
///
/// Next, select the Information Property List item, select Add Item from the
/// Editor menu, then select Localizations from the pop-up menu.
///
/// Select and expand the newly-created Localizations item then, for each
/// locale your application supports, add a new item and select the locale
/// you wish to add from the pop-up menu in the Value field. This list should
/// be consistent with the languages listed in the AppLocalizations.supportedLocales
/// property.
abstract class AppLocalizations {
  AppLocalizations(String locale) : localeName = intl.Intl.canonicalizedLocale(locale.toString());

  final String localeName;

  static AppLocalizations? of(BuildContext context) {
    return Localizations.of<AppLocalizations>(context, AppLocalizations);
  }

  static const LocalizationsDelegate<AppLocalizations> delegate = _AppLocalizationsDelegate();

  /// A list of this localizations delegate along with the default localizations
  /// delegates.
  ///
  /// Returns a list of localizations delegates containing this delegate along with
  /// GlobalMaterialLocalizations.delegate, GlobalCupertinoLocalizations.delegate,
  /// and GlobalWidgetsLocalizations.delegate.
  ///
  /// Additional delegates can be added by appending to this list in
  /// MaterialApp. This list does not have to be used at all if a custom list
  /// of delegates is preferred or required.
  static const List<LocalizationsDelegate<dynamic>> localizationsDelegates = <LocalizationsDelegate<dynamic>>[
    delegate,
    GlobalMaterialLocalizations.delegate,
    GlobalCupertinoLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ];

  /// A list of this localizations delegate's supported locales.
  static const List<Locale> supportedLocales = <Locale>[
    Locale('en'),
    Locale('es'),
    Locale('pt')
  ];

  /// No description provided for @userNameScreenTitle.
  ///
  /// In pt, this message translates to:
  /// **'Entrar com credenciais'**
  String get userNameScreenTitle;

  /// No description provided for @userNameScreenSubTitle.
  ///
  /// In pt, this message translates to:
  /// **'Entrar na conta'**
  String get userNameScreenSubTitle;

  /// No description provided for @loginBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Entrar'**
  String get loginBtnText;

  /// No description provided for @tenantNotFoundErrorMessage.
  ///
  /// In pt, this message translates to:
  /// **'Tenant não encontrado. Por favor, tente novamente.'**
  String get tenantNotFoundErrorMessage;

  /// No description provided for @genericErrorMessage.
  ///
  /// In pt, this message translates to:
  /// **'Houve um problema. Por favor, tente novamente.'**
  String get genericErrorMessage;

  /// No description provided for @unauthorizedErrorMessage.
  ///
  /// In pt, this message translates to:
  /// **'Email ou senha incorretos. Por favor, tente novamente.'**
  String get unauthorizedErrorMessage;

  /// No description provided for @ok.
  ///
  /// In pt, this message translates to:
  /// **'Ok'**
  String get ok;

  /// No description provided for @nextBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Avançar'**
  String get nextBtnText;

  /// No description provided for @passwordHint.
  ///
  /// In pt, this message translates to:
  /// **'Senha'**
  String get passwordHint;

  /// No description provided for @usernameHint.
  ///
  /// In pt, this message translates to:
  /// **'Login'**
  String get usernameHint;

  /// No description provided for @passwordRequiredMessage.
  ///
  /// In pt, this message translates to:
  /// **'Senha é obrigatória'**
  String get passwordRequiredMessage;

  /// No description provided for @usernameRequiredMessage.
  ///
  /// In pt, this message translates to:
  /// **'E-mail é obrigatório'**
  String get usernameRequiredMessage;

  /// No description provided for @usernameInvalidMessage.
  ///
  /// In pt, this message translates to:
  /// **'Usuário desconhecido'**
  String get usernameInvalidMessage;

  /// No description provided for @samlScreenTitle.
  ///
  /// In pt, this message translates to:
  /// **'Validação SAML'**
  String get samlScreenTitle;

  /// No description provided for @samlGreetingsMessage.
  ///
  /// In pt, this message translates to:
  /// **'Olá!'**
  String get samlGreetingsMessage;

  /// No description provided for @samlWelcomeMessage.
  ///
  /// In pt, this message translates to:
  /// **'Sua empresa utiliza camadas de segurança SAML para autenticação, por isso precisamos validar sua senha e login externamente.'**
  String get samlWelcomeMessage;

  /// No description provided for @samlValidateCredentialsBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Validar credenciais'**
  String get samlValidateCredentialsBtnText;

  /// No description provided for @samlCheckboxMessage.
  ///
  /// In pt, this message translates to:
  /// **'Não mostrar esta mensagem novamente.'**
  String get samlCheckboxMessage;

  /// No description provided for @authenticationCode.
  ///
  /// In pt, this message translates to:
  /// **'Código de autenticação'**
  String get authenticationCode;

  /// No description provided for @insertAuthenticationCodeMessage.
  ///
  /// In pt, this message translates to:
  /// **'Insira o código de 6 dígitos'**
  String get insertAuthenticationCodeMessage;

  /// No description provided for @insertAuthenticationCodeMessageBody.
  ///
  /// In pt, this message translates to:
  /// **'O código pode ser obtido no seu aplicativo autenticador.'**
  String get insertAuthenticationCodeMessageBody;

  /// No description provided for @unauthorizedErrorMessageMfaCode.
  ///
  /// In pt, this message translates to:
  /// **'Codigo de autenticação incorreto. Por favor, tente novamente.'**
  String get unauthorizedErrorMessageMfaCode;

  /// No description provided for @sendBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Enviar'**
  String get sendBtnText;

  /// No description provided for @pasteCode.
  ///
  /// In pt, this message translates to:
  /// **'Colar código copiado?'**
  String get pasteCode;

  /// Texto que pergunta se quer colar o code.
  ///
  /// In pt, this message translates to:
  /// **'Você deseja colar o código {code}?'**
  String youWantToPasteCode(String code);

  /// No description provided for @multifactorAuthentication.
  ///
  /// In pt, this message translates to:
  /// **'Autenticação de multifator'**
  String get multifactorAuthentication;

  /// No description provided for @paste.
  ///
  /// In pt, this message translates to:
  /// **'Colar'**
  String get paste;

  /// No description provided for @cancel.
  ///
  /// In pt, this message translates to:
  /// **'Cancelar'**
  String get cancel;

  /// No description provided for @invalidCode.
  ///
  /// In pt, this message translates to:
  /// **'Código inserido e inválido ou expirado. por favor, tente novamente.'**
  String get invalidCode;

  /// No description provided for @firstAuthenticationMultifactor.
  ///
  /// In pt, this message translates to:
  /// **'Para seu primeiro acesso, é necessário configurar seu usuário para realizar a autenticação de duplo fator. \n\nA configuração deve ser feita via e-mail.'**
  String get firstAuthenticationMultifactor;

  /// No description provided for @redefineAuthenticationMultifactor.
  ///
  /// In pt, this message translates to:
  /// **'Sua configuração de MFA foi redefinida pelo administrador, por favor configure-a novamente.'**
  String get redefineAuthenticationMultifactor;

  /// No description provided for @requestSendEmail.
  ///
  /// In pt, this message translates to:
  /// **'Solicitação envidada para o email.'**
  String get requestSendEmail;

  /// Texto que explica o que deve ser feito a seguir.
  ///
  /// In pt, this message translates to:
  /// **'Enviamos um email para {email}. Verifique seu e-mail para prosseguir com o processo.'**
  String requestSendEmailMessage(String email);

  /// No description provided for @back.
  ///
  /// In pt, this message translates to:
  /// **'Voltar'**
  String get back;

  /// No description provided for @requestConfig.
  ///
  /// In pt, this message translates to:
  /// **'Solicitar configuração'**
  String get requestConfig;

  /// No description provided for @genericErrorTitle.
  ///
  /// In pt, this message translates to:
  /// **'Erro ao carregar as informações.'**
  String get genericErrorTitle;

  /// No description provided for @genericErrorDescription.
  ///
  /// In pt, this message translates to:
  /// **'Tente novamente em alguns instantes.'**
  String get genericErrorDescription;

  /// No description provided for @recoveryPasswordBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Recuperar senha'**
  String get recoveryPasswordBtnText;

  /// No description provided for @recoveryPasswordTitle.
  ///
  /// In pt, this message translates to:
  /// **'Enviar e-mail para redefinição da senha?'**
  String get recoveryPasswordTitle;

  /// No description provided for @recoveryPasswordDescription.
  ///
  /// In pt, this message translates to:
  /// **'Enviaremos um e-mail para {email}. Após confirmar, verifique este e-mail para redefinir a senha.'**
  String recoveryPasswordDescription(Object email);

  /// No description provided for @recoveryPasswordSendEmailBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Enviar e-mail'**
  String get recoveryPasswordSendEmailBtnText;

  /// No description provided for @recoveryPasswordRecaptchaTitle.
  ///
  /// In pt, this message translates to:
  /// **'Por favor, preencha o recaptcha para continuar'**
  String get recoveryPasswordRecaptchaTitle;

  /// No description provided for @continueBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Continuar'**
  String get continueBtnText;

  /// No description provided for @recoveryPasswordFinishedTitle.
  ///
  /// In pt, this message translates to:
  /// **'Solicitação de redefinição de senha enviada para seu e-mail.'**
  String get recoveryPasswordFinishedTitle;

  /// No description provided for @recoveryPasswordFinishedDescription.
  ///
  /// In pt, this message translates to:
  /// **'Confira sua caixa de entrada. Caso seja um usuário cadastrado, enviaremos um e-mail com as instruções para a recuperação da senha.'**
  String get recoveryPasswordFinishedDescription;

  /// No description provided for @backToBeginingBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Voltar ao início'**
  String get backToBeginingBtnText;

  /// No description provided for @help.
  ///
  /// In pt, this message translates to:
  /// **'Ajuda'**
  String get help;

  /// No description provided for @helpTextLoginAuthenticationTitle.
  ///
  /// In pt, this message translates to:
  /// **'Esqueceu seu login ou está com problemas para entrar no aplicativo?'**
  String get helpTextLoginAuthenticationTitle;

  /// No description provided for @helpTextLoginAuthenticationDescriptio11.
  ///
  /// In pt, this message translates to:
  /// **'Seu login é formado por '**
  String get helpTextLoginAuthenticationDescriptio11;

  /// No description provided for @helpTextLoginAuthenticationDescriptio12.
  ///
  /// In pt, this message translates to:
  /// **'usuario@dominio.com.br '**
  String get helpTextLoginAuthenticationDescriptio12;

  /// No description provided for @helpTextLoginAuthenticationDescriptio13.
  ///
  /// In pt, this message translates to:
  /// **'(digitado sem acentos).'**
  String get helpTextLoginAuthenticationDescriptio13;

  /// No description provided for @helpTextLoginAuthenticationDescriptio2.
  ///
  /// In pt, this message translates to:
  /// **'Se você tem certeza de que as informações estão corretas e ainda estiver enfrentando problemas para entrar no aplicativo, '**
  String get helpTextLoginAuthenticationDescriptio2;

  /// No description provided for @helpTextLoginAuthenticationDescriptio21.
  ///
  /// In pt, this message translates to:
  /// **'verifique com o RH da sua empresa.'**
  String get helpTextLoginAuthenticationDescriptio21;

  /// No description provided for @helpTextLoginAuthenticationDescriptio3.
  ///
  /// In pt, this message translates to:
  /// **'Veja mais informações no '**
  String get helpTextLoginAuthenticationDescriptio3;

  /// No description provided for @helpTextDocumentationPortal.
  ///
  /// In pt, this message translates to:
  /// **'Portal de documentação'**
  String get helpTextDocumentationPortal;

  /// No description provided for @helpTextLoginMfaDescriptioTitle.
  ///
  /// In pt, this message translates to:
  /// **'O que é um aplicativo autenticador?'**
  String get helpTextLoginMfaDescriptioTitle;

  /// No description provided for @helpTextLoginMfaDescriptioTitle2.
  ///
  /// In pt, this message translates to:
  /// **'Como descobrir o aplicativo autenticador utilizado para o login?'**
  String get helpTextLoginMfaDescriptioTitle2;

  /// No description provided for @helpTextLoginMfaDescriptio1.
  ///
  /// In pt, this message translates to:
  /// **'O aplicativo autenticador é uma maneira segura e conveniente de provar quem você é.'**
  String get helpTextLoginMfaDescriptio1;

  /// No description provided for @helpTextLoginMfaDescriptio2.
  ///
  /// In pt, this message translates to:
  /// **'Nele gera-se códigos de verificação em dois fatores no seu celular.'**
  String get helpTextLoginMfaDescriptio2;

  /// No description provided for @helpTextLoginMfaDescriptio3.
  ///
  /// In pt, this message translates to:
  /// **'Copie o código oferecido no autenticador e informe aqui este código.'**
  String get helpTextLoginMfaDescriptio3;

  /// No description provided for @helpTextLoginMfaDescriptio4.
  ///
  /// In pt, this message translates to:
  /// **'Verifique com o RH de sua empresa ou veja mais informações do '**
  String get helpTextLoginMfaDescriptio4;

  /// No description provided for @resetPasswordScreenTitle.
  ///
  /// In pt, this message translates to:
  /// **'Nova senha'**
  String get resetPasswordScreenTitle;

  /// No description provided for @resetPasswordScreenSubtitle.
  ///
  /// In pt, this message translates to:
  /// **'Criar nova senha'**
  String get resetPasswordScreenSubtitle;

  /// No description provided for @resetPasswordScreenDescription.
  ///
  /// In pt, this message translates to:
  /// **'Para prosseguir, é preciso que você crie uma nova senha:'**
  String get resetPasswordScreenDescription;

  /// No description provided for @newPasswordHint.
  ///
  /// In pt, this message translates to:
  /// **'Nova senha'**
  String get newPasswordHint;

  /// No description provided for @confirmNewPasswordHint.
  ///
  /// In pt, this message translates to:
  /// **'Confirme sua nova senha'**
  String get confirmNewPasswordHint;

  /// No description provided for @resetPasswordBtnText.
  ///
  /// In pt, this message translates to:
  /// **'Redefinir senha'**
  String get resetPasswordBtnText;

  /// Password length policy
  ///
  /// In pt, this message translates to:
  /// **'Utilize no mínimo {minimumLength} e no máximo {maximumLength} caracteres.'**
  String passwordPolicyMinimumLength(int minimumLength, int maximumLength);

  /// No description provided for @passwordPolicyRequireNumbers.
  ///
  /// In pt, this message translates to:
  /// **'Sua senha precisa conter números.'**
  String get passwordPolicyRequireNumbers;

  /// No description provided for @passwordPolicyRequireLowerCase.
  ///
  /// In pt, this message translates to:
  /// **'Utilize pelo menos uma letra minúscula.'**
  String get passwordPolicyRequireLowerCase;

  /// No description provided for @passwordPolicyRequireUpperCase.
  ///
  /// In pt, this message translates to:
  /// **'Utilize pelo menos uma letra maiúscula.'**
  String get passwordPolicyRequireUpperCase;

  /// No description provided for @passwordPolicyRequireSpecialCharacters.
  ///
  /// In pt, this message translates to:
  /// **'Sua senha precisa conter caracteres especiais.'**
  String get passwordPolicyRequireSpecialCharacters;

  /// No description provided for @passwordPolicyPasswordConfirmPasswordMatches.
  ///
  /// In pt, this message translates to:
  /// **'A senha e a confirmação da senha devem ser iguais.'**
  String get passwordPolicyPasswordConfirmPasswordMatches;

  /// No description provided for @usernameTextfieldHintText.
  ///
  /// In pt, this message translates to:
  /// **'usuario@dominio.com.br'**
  String get usernameTextfieldHintText;

  /// No description provided for @loginWithKeyConfigurationKey.
  ///
  /// In pt, this message translates to:
  /// **'Configuração da chave'**
  String get loginWithKeyConfigurationKey;

  /// No description provided for @loginWithKeyTitle.
  ///
  /// In pt, this message translates to:
  /// **'Informe a chave de acesso para configuração do dispositivo'**
  String get loginWithKeyTitle;

  /// No description provided for @loginWithKeyHelperKey.
  ///
  /// In pt, this message translates to:
  /// **'Você pode encontrar a chave na plataforma'**
  String get loginWithKeyHelperKey;

  /// No description provided for @loginWithKeyHelperDomain.
  ///
  /// In pt, this message translates to:
  /// **'Você pode encontrar o domínio na plataforma'**
  String get loginWithKeyHelperDomain;

  /// No description provided for @loginWithKeyWrongDomain.
  ///
  /// In pt, this message translates to:
  /// **'Domínio não encontrado'**
  String get loginWithKeyWrongDomain;

  /// No description provided for @loginWithKeyHelperSecret.
  ///
  /// In pt, this message translates to:
  /// **'Você pode encontrar o segredo na plataforma'**
  String get loginWithKeyHelperSecret;

  /// No description provided for @loginWithKeyWrongKey.
  ///
  /// In pt, this message translates to:
  /// **'Chave de acesso incorreta'**
  String get loginWithKeyWrongKey;

  /// No description provided for @loginWithKeyWrongSecret.
  ///
  /// In pt, this message translates to:
  /// **'Segredo incorreto'**
  String get loginWithKeyWrongSecret;

  /// No description provided for @loginWithKeyAccessKey.
  ///
  /// In pt, this message translates to:
  /// **'Chave de acesso'**
  String get loginWithKeyAccessKey;

  /// No description provided for @loginWithKeySecret.
  ///
  /// In pt, this message translates to:
  /// **'Segredo'**
  String get loginWithKeySecret;

  /// No description provided for @loginWithKeyDomain.
  ///
  /// In pt, this message translates to:
  /// **'Domínio'**
  String get loginWithKeyDomain;

  /// No description provided for @loginWithKeyHelper.
  ///
  /// In pt, this message translates to:
  /// **'As informações devem ser obtidas junto ao administrador do sistema de sua empresa, contate o RH para obter mais informações.'**
  String get loginWithKeyHelper;

  /// No description provided for @loginWithKeyDomainNotFound.
  ///
  /// In pt, this message translates to:
  /// **'Domínio não encontrado'**
  String get loginWithKeyDomainNotFound;

  /// No description provided for @loginWithKeyUnauthorizedErrorMessage.
  ///
  /// In pt, this message translates to:
  /// **'Chave ou segredo incorretos. Por favor, tente novamente.'**
  String get loginWithKeyUnauthorizedErrorMessage;

  /// No description provided for @loginWithKeyHelpTitle.
  ///
  /// In pt, this message translates to:
  /// **'Precisa de ajuda?'**
  String get loginWithKeyHelpTitle;

  /// No description provided for @loginWithKeyUnauthorizedErrorHelper.
  ///
  /// In pt, this message translates to:
  /// **'Chave ou segredo incorretos'**
  String get loginWithKeyUnauthorizedErrorHelper;

  /// No description provided for @enableAccessWithBiometricsTitle.
  ///
  /// In pt, this message translates to:
  /// **'Habilitar acesso com biometria?'**
  String get enableAccessWithBiometricsTitle;

  /// No description provided for @enableAccessWithBiometricsContent.
  ///
  /// In pt, this message translates to:
  /// **'Quando esta função estiver ativada, você precisará usar a biometria para desbloquear o aplicativo. Você poderá alterar essa opção em Configurações.'**
  String get enableAccessWithBiometricsContent;

  /// No description provided for @yes.
  ///
  /// In pt, this message translates to:
  /// **'Sim'**
  String get yes;

  /// No description provided for @no.
  ///
  /// In pt, this message translates to:
  /// **'Não'**
  String get no;

  /// No description provided for @accountAccessWithBiometrics.
  ///
  /// In pt, this message translates to:
  /// **'Acesso à conta com biometria'**
  String get accountAccessWithBiometrics;

  /// No description provided for @unregisteredSecurityMethods.
  ///
  /// In pt, this message translates to:
  /// **'Métodos de segurança não cadastrados'**
  String get unregisteredSecurityMethods;

  /// No description provided for @unregisteredSecurityMethodsContent.
  ///
  /// In pt, this message translates to:
  /// **'Para utilizar esta opção, por favor, ative a biometria ou outro método de segurança nas configurações do seu dispositivo. Retorne ao aplicativo e habilite a opção em Configurações.'**
  String get unregisteredSecurityMethodsContent;
}

class _AppLocalizationsDelegate extends LocalizationsDelegate<AppLocalizations> {
  const _AppLocalizationsDelegate();

  @override
  Future<AppLocalizations> load(Locale locale) {
    return SynchronousFuture<AppLocalizations>(lookupAppLocalizations(locale));
  }

  @override
  bool isSupported(Locale locale) => <String>['en', 'es', 'pt'].contains(locale.languageCode);

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;
}

AppLocalizations lookupAppLocalizations(Locale locale) {


  // Lookup logic when only language code is specified.
  switch (locale.languageCode) {
    case 'en': return AppLocalizationsEn();
    case 'es': return AppLocalizationsEs();
    case 'pt': return AppLocalizationsPt();
  }

  throw FlutterError(
    'AppLocalizations.delegate failed to load unsupported locale "$locale". This is likely '
    'an issue with the localizations generation tool. Please file an issue '
    'on GitHub with a reproducible sample app and the gen-l10n configuration '
    'that was used.'
  );
}
