import 'package:local_auth/local_auth.dart';

import '../../../../../../senior_platform_authentication_ui.dart';

abstract class BiometricDatasource {
  Future<bool> canCheckBiometrics();
  Future<BiometryStatus> biometricsAuthenticate(
      {required String localizedReason});
  Future<bool> getAvailableBiometrics();
}

class BiometricDatasourceImpl implements BiometricDatasource {
  late final LocalAuthentication _localAuthentication;

  BiometricDatasourceImpl({
    LocalAuthentication? localAuthentication,
  }) {
    _localAuthentication = localAuthentication ?? LocalAuthentication();
  }

  //Checks if your device supports biometrics and if it is enabled
  @override
  Future<bool> canCheckBiometrics() async {
    try {
      return await _localAuthentication.canCheckBiometrics;
    } catch (e) {
      return false;
    }
  }

  //Authenticate the user using biometrics
  @override
  Future<BiometryStatus> biometricsAuthenticate(
      {required String localizedReason}) async {
    BiometryStatus biometryStatus = BiometryStatus.unknown;
    bool authenticated = false;

    try {
      authenticated = await _localAuthentication.authenticate(
        //message that will appear on the biometrics screen
        localizedReason: localizedReason,
        options: AuthenticationOptions(
          sensitiveTransaction: true,
          biometricOnly: SeniorAuthentication.enableBiometryOnly,
        ),
      );
      authenticated
          ? biometryStatus = BiometryStatus.success
          : biometryStatus = BiometryStatus.canceled;
    } catch (e) {
      biometryStatus = BiometryStatus.error;
    }

    return biometryStatus;
  }

  @override
  Future<bool> getAvailableBiometrics() async {
    try {
      final availableBiometrics =
          await _localAuthentication.getAvailableBiometrics();

      return availableBiometrics.isNotEmpty;
    } catch (e) {
      return false;
    }
  }
}
