// ignore_for_file: prefer_const_constructors

import 'package:bloc_test/bloc_test.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mocktail/mocktail.dart';
import 'package:senior_platform_authentication_ui/senior_platform_authentication_ui.dart';

import '../../../../../mocks/application_key_mock.dart';
import '../../../../../mocks/authentication_data_mock.dart';
import '../../../../../mocks/get_user_input_mock.dart';
import '../../../../../mocks/key_authentication_data_mock.dart';
import '../../../../../mocks/token_mock.dart';
import '../../../../../mocks/user_mock.dart';

class MockGetUserUsecase extends Mock implements GetUserUsecase {}

class MockStoreAuthenticationDataUsecase extends Mock
    implements StoreAuthenticationDataUsecase {}

class MockCheckStoredTokenUsecase extends Mock
    implements CheckStoredTokenUsecase {}

class MockLogoutOnlineUsecase extends Mock implements LogoutUsecase {}

class MockClearStoredDataUsecase extends Mock
    implements ClearStoredDataUsecase {}

class MockGetStoredTokenUsecase extends Mock implements GetStoredTokenUsecase {}

class MockRefreshStoredTokenUsecase extends Mock
    implements RefreshStoredTokenUsecase {}

class MockCheckStatusConnectionUsecase extends Mock
    implements CheckStatusConnectionUsecase {}

class MockAuthenticateKeyUsecase extends Mock
    implements AuthenticateKeyUsecase {}

class MockCheckKeyStoredTokenUsecase extends Mock
    implements CheckKeyStoredTokenUsecase {}

class MockClearKeyStoredDataUsecase extends Mock
    implements ClearKeyStoredDataUsecase {}

class MockGetStoredKeyTokenUsecase extends Mock
    implements GetStoredKeyTokenUsecase {}

class MockGetStoredKeyUsecase extends Mock implements GetStoredKeyUsecase {}

class MockRefreshKeyStoredTokenUsecase extends Mock
    implements RefreshKeyStoredTokenUsecase {}

class MockStoreKeyAuthenticationDataUsecase extends Mock
    implements StoreKeyAuthenticationDataUsecase {}

class MockBiometricAuthenticationUsecase extends Mock
    implements BiometricCanCheckUseCase {}

class MockBiometricAuthAuthenticateUseCase extends Mock
    implements BiometricAuthenticateUsecase {}

class MockBiometricAuthCanAuthenticateUseCase extends Mock
    implements BiometricCanCheckUseCase {}

class MockGetStoredUserUsecase extends Mock implements GetStoredUserUsecase {}

void main() {
  late GetUserUsecase getUserUsecase;
  late StoreAuthenticationDataUsecase storeAuthenticationDataUsecase;
  late CheckStoredTokenUsecase checkStoredTokenUsecase;
  late LogoutUsecase logoutOnlineUsecase;
  late ClearStoredDataUsecase clearStoredDataUsecase;
  late GetStoredTokenUsecase getStoredTokenUsecase;
  late AuthenticationBloc authenticationBloc;
  late RefreshStoredTokenUsecase refreshStoredTokenUsecase;
  late CheckStatusConnectionUsecase checkStatusConnectionUsecase;
  late AuthenticateKeyUsecase authenticateKeyUsecase;
  late CheckKeyStoredTokenUsecase checkKeyStoredTokenUsecase;
  late ClearKeyStoredDataUsecase clearKeyStoredDataUsecase;
  late GetStoredKeyTokenUsecase getStoredKeyTokenUsecase;
  late GetStoredKeyUsecase getStoredKeyUsecase;
  late RefreshKeyStoredTokenUsecase refreshKeyStoredTokenUsecase;
  late StoreKeyAuthenticationDataUsecase storeAppKeyAuthenticationDataUsecase;
  late BiometricCanCheckUseCase biometricAuthCanAuthenticateUseCase;
  late BiometricAuthenticateUsecase biometricAuthAuthenticateUseCase;
  late GetStoredUserUsecase getStoredUserUsecase;
  const String tUsername = 'username';
  const String tAccessKey = 'accessKey';

  setUpAll(() {
    SeniorAuthentication.initialize(
      enableBiometry: true,
      enableBiometryOnly: true,
    );
  });

  setUp(() {
    getUserUsecase = MockGetUserUsecase();
    storeAuthenticationDataUsecase = MockStoreAuthenticationDataUsecase();
    checkStoredTokenUsecase = MockCheckStoredTokenUsecase();
    logoutOnlineUsecase = MockLogoutOnlineUsecase();
    getStoredTokenUsecase = MockGetStoredTokenUsecase();
    clearStoredDataUsecase = MockClearStoredDataUsecase();
    refreshStoredTokenUsecase = MockRefreshStoredTokenUsecase();
    checkStatusConnectionUsecase = MockCheckStatusConnectionUsecase();
    authenticateKeyUsecase = MockAuthenticateKeyUsecase();
    checkKeyStoredTokenUsecase = MockCheckKeyStoredTokenUsecase();
    clearKeyStoredDataUsecase = MockClearKeyStoredDataUsecase();
    getStoredKeyTokenUsecase = MockGetStoredKeyTokenUsecase();
    getStoredKeyUsecase = MockGetStoredKeyUsecase();
    refreshKeyStoredTokenUsecase = MockRefreshKeyStoredTokenUsecase();
    storeAppKeyAuthenticationDataUsecase =
        MockStoreKeyAuthenticationDataUsecase();

    biometricAuthCanAuthenticateUseCase =
        MockBiometricAuthCanAuthenticateUseCase();
    biometricAuthAuthenticateUseCase = MockBiometricAuthAuthenticateUseCase();
    getStoredUserUsecase = MockGetStoredUserUsecase();
    authenticationBloc = AuthenticationBloc.mocked(
      getUserUsecase: getUserUsecase,
      storeAuthenticationDataUsecase: storeAuthenticationDataUsecase,
      checkStoredTokenUsecase: checkStoredTokenUsecase,
      logoutOnlineUsecase: logoutOnlineUsecase,
      clearStoredDataUsecase: clearStoredDataUsecase,
      getStoredTokenUsecase: getStoredTokenUsecase,
      refreshStoredTokenUsecase: refreshStoredTokenUsecase,
      checkStatusConnectionUsecase: checkStatusConnectionUsecase,
      authenticateKeyUsecase: authenticateKeyUsecase,
      checkKeyStoredTokenUsecase: checkKeyStoredTokenUsecase,
      clearKeyStoredDataUsecase: clearKeyStoredDataUsecase,
      getStoredKeyTokenUsecase: getStoredKeyTokenUsecase,
      getStoredKeyUsecase: getStoredKeyUsecase,
      refreshKeyStoredTokenUsecase: refreshKeyStoredTokenUsecase,
      storeAppKeyAuthenticationDataUsecase:
          storeAppKeyAuthenticationDataUsecase,
      biometricAuthCanAuthenticateUseCase: biometricAuthCanAuthenticateUseCase,
      biometricAuthAuthenticateUseCase: biometricAuthAuthenticateUseCase,
      getStoredUserUsecase: getStoredUserUsecase,
    );
    registerFallbackValue(authenticationDataMock);
    registerFallbackValue(NoParams());
    registerFallbackValue(UserName());
    registerFallbackValue(getUserInputMock);
  });

  group('factory', () {
    test('AuthenticationBloc factory', () {
      final leafAuthenticationBloc = AuthenticationBloc();
      expect(leafAuthenticationBloc, isA<AuthenticationBloc>());
    });
  });

  group('onAuthenticationStatusChanged', () {
    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unknown] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.unknown',
      build: () => authenticationBloc,
      act: (bloc) => bloc
          .add(const AuthenticationStatusChanged(AuthenticationStatus.unknown)),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unknown(),
      ],
      verify: (_) async {
        verifyNever(() => getUserUsecase.call(any()));
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.unauthenticated',
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(const AuthenticationStatusChanged(
          AuthenticationStatus.unauthenticated)),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unauthenticated(),
      ],
      verify: (_) async {
        verifyNever(() => getUserUsecase.call(any()));
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.authenticated '
      'and verify usecases call',
      setUp: () {
        when(() => getUserUsecase.call(any()))
            .thenAnswer((_) async => userMock);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(const AuthenticationStatusChanged(
        AuthenticationStatus.authenticated,
        authenticationResponse: authenticationResponseMock,
      )),
      expect: () => <AuthenticationState>[
        AuthenticationState.authenticated(username: tUsername),
      ],
      verify: (_) async {
        verify(() => getUserUsecase.call(any())).called(1);
        verify(() => storeAuthenticationDataUsecase.call(any())).called(1);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.authenticated and biometrics'
      'and verify usecases call',
      setUp: () {
        when(() => getUserUsecase.call(any()))
            .thenAnswer((_) async => userMock);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => getStoredUserUsecase.call(any()))
            .thenAnswer((_) async => userMock);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => biometricAuthCanAuthenticateUseCase.call(any()))
            .thenAnswer((_) async => true);
        when(() => biometricAuthAuthenticateUseCase.call(any())).thenAnswer(
          (_) async => BiometryStatus.success,
        );
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(
        const AuthenticationStatusChanged(AuthenticationStatus.authenticated,
            authenticationResponse: authenticationResponseMock,
            biometryStatus: BiometryStatus.success),
      ),
      expect: () => <AuthenticationState>[
        AuthenticationState.authenticated(username: tUsername),
      ],
      verify: (_) async {
        verify(() => getUserUsecase.call(any())).called(1);
        verify(() => storeAuthenticationDataUsecase.call(any())).called(1);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.offline',
      setUp: () {
        when(() => checkStatusConnectionUsecase.call(NoParams())).thenAnswer(
          (_) async => false,
        );
        when(() => getUserUsecase.call(any()))
            .thenAnswer((_) async => userMock);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(const AuthenticationStatusChanged(
        AuthenticationStatus.offline,
        authenticationResponse: authenticationResponseMock,
      )),
      expect: () => <AuthenticationState>[
        AuthenticationState.offline(tUsername),
      ],
      verify: (_) async {
        verifyNever(() => getUserUsecase.call(any()));
      },
    );
  });

  group('onLogoutOnlineRequested', () {
    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when LogoutOnlineRequested '
      'event if fired and verify usecases call',
      setUp: () {
        when(() => checkStatusConnectionUsecase.call(NoParams())).thenAnswer(
          (_) async => true,
        );
        when(() => getStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => tokenMock);
        when(() => logoutOnlineUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => clearStoredDataUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(LogoutOnlineRequested()),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unauthenticated(),
      ],
      verify: (_) async {
        verify(() => getStoredTokenUsecase.call(any())).called(1);
        verify(() => logoutOnlineUsecase.call(any())).called(1);
        verify(() => clearStoredDataUsecase.call(any())).called(1);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when LogoutOnlineRequested '
      'event if fired fail and verify usecases call',
      setUp: () {
        when(() => checkStatusConnectionUsecase.call(NoParams())).thenAnswer(
          (_) async => true,
        );
        when(() => getStoredTokenUsecase.call(any()))
            .thenThrow((_) async => Exception());
        when(() => logoutOnlineUsecase.call(any()))
            .thenAnswer((_) async => false);
        when(() => clearStoredDataUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(LogoutOnlineRequested()),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unauthenticated(),
      ],
      verify: (_) async {
        verify(() => getStoredTokenUsecase.call(any())).called(1);
        verifyNever(() => logoutOnlineUsecase.call(any()));
        verify(() => clearStoredDataUsecase.call(any())).called(1);
      },
    );
  });

  group('onCheckAuthenticationRequested', () {
    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when CheckAuthenticationRequested '
      'event if fired with valid token on storage and verify usecases call',
      setUp: () {
        when(() => checkStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => getStoredUserUsecase.call(any()))
            .thenAnswer((_) async => userMockNotBiometric);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      build: () => authenticationBloc,
      act: (bloc) =>
          bloc.add(CheckAuthenticationRequested(username: tUsername)),
      expect: () => <AuthenticationState>[
        AuthenticationState.authenticated(username: tUsername),
      ],
      verify: (_) async {
        verify(() => checkStoredTokenUsecase.call(any())).called(1);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when CheckAuthenticationRequested '
      'event if triggered with activated biometrics validating token and verify usecases call',
      setUp: () {
        when(() => checkStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => getStoredUserUsecase.call(any()))
            .thenAnswer((_) async => userMock);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => biometricAuthCanAuthenticateUseCase.call(any()))
            .thenAnswer((_) async => true);
        when(() => biometricAuthAuthenticateUseCase.call(any())).thenAnswer(
          (_) async => BiometryStatus.success,
        );
      },
      build: () => authenticationBloc,
      act: (bloc) =>
          bloc.add(CheckAuthenticationRequested(username: tUsername)),
      expect: () => <AuthenticationState>[
        AuthenticationState.authenticated(username: tUsername),
      ],
      verify: (_) async {
        verify(() => checkStoredTokenUsecase.call(any())).called(1);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when CheckAuthenticationRequested '
      'event if triggered with not activated biometrics validating token and verify usecases call',
      setUp: () {
        when(() => checkStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => false);
        when(() => refreshStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => null);
        when(() => getStoredUserUsecase.call(any()))
            .thenAnswer((_) async => userMockNotBiometric);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => biometricAuthCanAuthenticateUseCase.call(any()))
            .thenAnswer((_) async => true);
        when(() => biometricAuthAuthenticateUseCase.call(any()))
            .thenAnswer((_) async => BiometryStatus.canceled);
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(CheckAuthenticationRequested(
          username: tUsername, biometricMessage: 'biometricMessage')),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unauthenticated(),
      ],
      verify: (_) async {
        verify(() => checkStoredTokenUsecase.call(any())).called(1);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when CheckAuthenticationRequested '
      'event if fired with invalid token on storage and verify usecases call',
      setUp: () {
        when(() => checkStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => false);
        when(() => refreshStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => null);
        when(() => getStoredUserUsecase.call(any()))
            .thenAnswer((_) async => userMockNotBiometric);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(CheckAuthenticationRequested(
          username: tUsername, biometricMessage: 'biometricMessage')),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unauthenticated(),
      ],
      verify: (_) async {
        verify(() => checkStoredTokenUsecase.call(any())).called(1);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when CheckAuthenticationRequested '
      'event if fired with invalid token on storage and refreshToken usecases call',
      setUp: () {
        when(() => checkStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => false);
        when(() => refreshStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => tokenMock);
        when(() => getStoredUserUsecase.call(any()))
            .thenAnswer((_) async => userMockNotBiometric);
        when(() => storeAuthenticationDataUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      build: () => authenticationBloc,
      act: (bloc) =>
          bloc.add(CheckAuthenticationRequested(username: tUsername)),
      expect: () => <AuthenticationState>[
        AuthenticationState.authenticated(username: tUsername),
      ],
      verify: (_) async {
        verify(() => checkStoredTokenUsecase.call(any())).called(1);
        verify(() => refreshStoredTokenUsecase.call(any())).called(1);
      },
    );
  });

  group('onLogoutOfflineRequested', () {
    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when LogoutOfflineRequested default '
      'event if fired and verify usecases call ',
      setUp: () {
        when(() => getStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => tokenMock);
        when(() => clearStoredDataUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(LogoutOfflineRequested(username: tUsername)),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unauthenticated(),
      ],
      verify: (_) async {
        verify(() => getStoredTokenUsecase.call(any())).called(1);
        verify(() => clearStoredDataUsecase.call(any())).called(1);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when LogoutOfflineRequested erase token'
      'event if fired and verify usecases call',
      setUp: () {
        when(() => getStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => tokenMock);
        when(() => clearStoredDataUsecase.call(any()))
            .thenAnswer((_) async => false);
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(LogoutOfflineRequested(
        username: tUsername,
        eraseToken: true,
      )),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unauthenticated(),
      ],
      verify: (_) async {
        verify(() => getStoredTokenUsecase.call(any())).called(1);
        verify(() => clearStoredDataUsecase.call(any())).called(1);
      },
    );
  });

  group('onAuthenticateKey', () {
    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unknown] when AuthenticateKey '
      'event loginWithKey off and verify usecases call',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(AuthenticateKey(tAccessKey)),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unknown(),
      ],
      verify: (_) async {},
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when AuthenticateKey '
      'event loginWithKey on and verify usecases call',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        when(
          () => authenticateKeyUsecase.call(any()),
        ).thenAnswer((_) async => null);
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(AuthenticateKey(tAccessKey)),
      expect: () => <AuthenticationState>[
        const AuthenticationState.keyUnauthenticated(),
      ],
      verify: (_) async {
        verify(
          () => authenticateKeyUsecase.call(any()),
        ).called(1);
        verifyNoMoreInteractions(authenticateKeyUsecase);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when AuthenticateKey '
      'event loginWithKey on and verify usecases call',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        registerFallbackValue(keyAuthenticationDataMock);
        when(
          () => authenticateKeyUsecase.call(any()),
        ).thenAnswer((_) async => authenticationResponseMock);
        when(
          () => storeAppKeyAuthenticationDataUsecase.call(any()),
        ).thenAnswer((_) async => true);
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(AuthenticateKey(tAccessKey)),
      expect: () => <AuthenticationState>[
        const AuthenticationState.keyAuthenticated(),
      ],
      verify: (_) async {
        verify(
          () => authenticateKeyUsecase.call(any()),
        ).called(1);
        verify(
          () => storeAppKeyAuthenticationDataUsecase.call(any()),
        ).called(1);
        verifyNoMoreInteractions(authenticateKeyUsecase);
        verifyNoMoreInteractions(storeAppKeyAuthenticationDataUsecase);
      },
    );
  });

  group('onKeyAuthenticationStatusChanged', () {
    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unknown] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.unknown on LoginWithKey',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(
        const AuthenticationStatusChanged(AuthenticationStatus.unknown),
      ),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unknown(),
      ],
      verify: (_) async {
        verifyNever(() => getUserUsecase.call(any()));
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unknown] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.offline on LoginWithKey',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(
        const AuthenticationStatusChanged(AuthenticationStatus.offline),
      ),
      expect: () => <AuthenticationState>[
        const AuthenticationState.unknown(),
      ],
      verify: (_) async {
        verifyNever(() => getUserUsecase.call(any()));
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.unauthenticated on LoginWithKey',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(
        const AuthenticationStatusChanged(AuthenticationStatus.unauthenticated),
      ),
      expect: () => <AuthenticationState>[
        const AuthenticationState.keyUnauthenticated(),
      ],
      verify: (_) async {
        verifyNever(() => getUserUsecase.call(any()));
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.authenticated on LoginWithKey',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        registerFallbackValue(keyAuthenticationDataMock);
        when(
          () => storeAppKeyAuthenticationDataUsecase.call(any()),
        ).thenAnswer(
          (invocation) => Future.value(true),
        );
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(
        const AuthenticationStatusChanged(AuthenticationStatus.authenticated),
      ),
      expect: () => <AuthenticationState>[
        const AuthenticationState.keyAuthenticated(),
      ],
      verify: (_) async {
        verifyNever(() => getUserUsecase.call(any()));
        verify(
          () => storeAppKeyAuthenticationDataUsecase.call(any()),
        ).called(1);
        verifyNoMoreInteractions(storeAppKeyAuthenticationDataUsecase);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when AuthenticationStatusChanged '
      'event is fired with AuthenticationStatus.authenticated on LoginWithKey',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        registerFallbackValue(keyAuthenticationDataMock);
        when(
          () => storeAppKeyAuthenticationDataUsecase.call(any()),
        ).thenAnswer(
          (invocation) => Future.value(false),
        );
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(
        const AuthenticationStatusChanged(AuthenticationStatus.authenticated),
      ),
      expect: () => <AuthenticationState>[
        const AuthenticationState.keyUnauthenticated(),
      ],
      verify: (_) async {
        verifyNever(() => getUserUsecase.call(any()));
        verify(
          () => storeAppKeyAuthenticationDataUsecase.call(any()),
        ).called(1);
        verifyNoMoreInteractions(storeAppKeyAuthenticationDataUsecase);
      },
    );
  });

  group('onKeyLogoutOnlineRequested', () {
    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when LogoutOnlineRequested '
      'event if fired and verify usecases call',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        when(() => getStoredKeyUsecase.call(null)).thenAnswer(
          (_) async => applicationKeyMock,
        );
        when(() => checkStatusConnectionUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => getStoredKeyTokenUsecase.call(any()))
            .thenAnswer((_) async => tokenMock);
        when(() => logoutOnlineUsecase.call(any()))
            .thenAnswer((_) async => true);
        when(() => clearKeyStoredDataUsecase.call(any()))
            .thenAnswer((_) async => Future.value());
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(LogoutOnlineRequested()),
      expect: () => <AuthenticationState>[
        const AuthenticationState.keyUnauthenticated(),
      ],
      verify: (_) async {
        verify(() => getStoredKeyUsecase.call(null)).called(1);
        verify(() => checkStatusConnectionUsecase.call(any())).called(1);
        verify(() => getStoredKeyTokenUsecase.call(any())).called(1);
        verify(() => logoutOnlineUsecase.call(any())).called(1);
        verify(() => clearKeyStoredDataUsecase.call(any())).called(1);

        verifyNoMoreInteractions(getStoredKeyUsecase);
        verifyNoMoreInteractions(checkStatusConnectionUsecase);
        verifyNoMoreInteractions(getStoredKeyTokenUsecase);
        verifyNoMoreInteractions(logoutOnlineUsecase);
        verifyNoMoreInteractions(clearKeyStoredDataUsecase);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when LogoutOnlineRequested '
      'event throws and verify usecases call',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        when(() => getStoredKeyUsecase.call(null)).thenAnswer(
          (_) async => applicationKeyMock,
        );
        when(() => checkStatusConnectionUsecase.call(any()))
            .thenThrow((_) async => Exception());
        when(() => clearKeyStoredDataUsecase.call(any()))
            .thenAnswer((_) async => Future.value());
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) => bloc.add(LogoutOnlineRequested()),
      expect: () => <AuthenticationState>[
        const AuthenticationState.keyUnauthenticated(),
      ],
      verify: (_) async {
        verify(() => getStoredKeyUsecase.call(null)).called(1);
        verify(() => checkStatusConnectionUsecase.call(any())).called(1);
        verify(() => clearKeyStoredDataUsecase.call(any())).called(1);

        verifyNoMoreInteractions(getStoredKeyUsecase);
        verifyNoMoreInteractions(checkStatusConnectionUsecase);
        verifyNoMoreInteractions(clearKeyStoredDataUsecase);
      },
    );
  });

  group('onCheckKeyAuthenticationRequested', () {
    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when CheckAuthenticationRequested '
      'event if fired with valid token on storage and verify usecases call',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        when(() => checkKeyStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => true);
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) =>
          bloc.add(CheckAuthenticationRequested(accesskey: tAccessKey)),
      expect: () => <AuthenticationState>[
        AuthenticationState.keyAuthenticated(accessKey: tAccessKey),
      ],
      verify: (_) async {
        verify(() => checkKeyStoredTokenUsecase.call(any())).called(1);
        verifyNoMoreInteractions(checkKeyStoredTokenUsecase);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.authenticated] when CheckAuthenticationRequested '
      'event if fired with invalid token on storage and verify usecases call',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        when(() => checkKeyStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => false);

        when(
          () => refreshKeyStoredTokenUsecase.call(any()),
        ).thenAnswer((_) => Future.value(tokenMock));
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) =>
          bloc.add(CheckAuthenticationRequested(accesskey: tAccessKey)),
      expect: () => <AuthenticationState>[
        AuthenticationState.keyAuthenticated(accessKey: tAccessKey),
      ],
      verify: (_) async {
        verify(() => checkKeyStoredTokenUsecase.call(any())).called(1);
        verify(() => refreshKeyStoredTokenUsecase.call(any())).called(1);
        verifyNoMoreInteractions(checkKeyStoredTokenUsecase);
        verifyNoMoreInteractions(refreshKeyStoredTokenUsecase);
      },
    );

    blocTest<AuthenticationBloc, AuthenticationState>(
      'emits [AuthenticationState.unauthenticated] when CheckAuthenticationRequested '
      'event if fired with invalid token on storage and verify usecases call',
      setUp: () {
        SeniorAuthentication.enableLoginWithKey = true;
        when(() => checkKeyStoredTokenUsecase.call(any()))
            .thenAnswer((_) async => false);

        when(
          () => refreshKeyStoredTokenUsecase.call(any()),
        ).thenAnswer((_) => Future.value(null));
      },
      tearDown: () {
        SeniorAuthentication.enableLoginWithKey = false;
      },
      build: () => authenticationBloc,
      act: (bloc) =>
          bloc.add(CheckAuthenticationRequested(accesskey: tAccessKey)),
      expect: () => <AuthenticationState>[
        AuthenticationState.keyUnauthenticated(),
      ],
      verify: (_) async {
        verify(() => checkKeyStoredTokenUsecase.call(any())).called(1);
        verify(() => refreshKeyStoredTokenUsecase.call(any())).called(1);
        verifyNoMoreInteractions(checkKeyStoredTokenUsecase);
        verifyNoMoreInteractions(refreshKeyStoredTokenUsecase);
      },
    );
  });
}
