// ignore_for_file: prefer_const_constructors, prefer_const_declarations

import 'package:flutter_test/flutter_test.dart';
import 'package:senior_platform_authentication_ui/senior_platform_authentication_ui.dart';

import '../../../../../mocks/mfa_info_mock.dart';
import '../../../../../mocks/token_mock.dart';

void main() {
  const tAccessKey = 'tAccessKey';

  group('AuthenticationEventTest', () {
    test(
        'Should event be AuthenticationEventTest when '
        'call AuthenticationStatusChanged constructor', () {
      //Arrange
      final tResponse = AuthenticationResponse(
          token: tokenMock, mfaInfo: mfaInfoUnconfiguredMock);
      final status = AuthenticationStatus.authenticated;
      final isBiometricEnabled = BiometryStatus.success;
      //Act
      var tAuthenticationStatusChanged = AuthenticationStatusChanged(
        authenticationResponse: tResponse,
        status,
        biometryStatus: isBiometricEnabled,
      );

      //Assert
      expect(
        tAuthenticationStatusChanged,
        isA<AuthenticationEvent>(),
      );

      expect(
        tAuthenticationStatusChanged,
        AuthenticationStatusChanged(
            authenticationResponse: tResponse,
            status,
            biometryStatus: isBiometricEnabled),
      );
    });

    test(
        'Should event be AuthenticationEventTest when '
        'call AuthenticationStatusChanged constructor Without isBiometricEnabled and with your return false',
        () {
      //Arrange
      final tResponse = AuthenticationResponse(
          token: tokenMock, mfaInfo: mfaInfoUnconfiguredMock);
      final status = AuthenticationStatus.authenticated;
      //Act
      var tAuthenticationStatusChanged = AuthenticationStatusChanged(
        authenticationResponse: tResponse,
        status,
      );

      //Assert
      expect(
        tAuthenticationStatusChanged,
        isA<AuthenticationEvent>(),
      );

      expect(
        tAuthenticationStatusChanged,
        AuthenticationStatusChanged(
          authenticationResponse: tResponse,
          status,
          biometryStatus: BiometryStatus.unknown,
        ),
      );
    });

    test(
        'Should event be AuthenticationEventTest when '
        'call LogoutOnlineRequested constructor', () {
      //Act
      var tLogoutOnlineRequested = LogoutOnlineRequested();

      //Assert
      expect(
        tLogoutOnlineRequested,
        isA<AuthenticationEvent>(),
      );

      expect(tLogoutOnlineRequested.props.isEmpty, true);

      expect(
        tLogoutOnlineRequested,
        LogoutOnlineRequested(),
      );
    });

    test(
        'Should event be AuthenticationEventTest when '
        'call CheckAuthenticationRequested constructor', () {
      //Arrange
      final tUsername = 'teste@senior.com.br';

      //Act
      var tLogoutOnlineRequested = CheckAuthenticationRequested(
        username: tUsername,
        accesskey: tAccessKey,
      );

      //Assert
      expect(
        tLogoutOnlineRequested,
        isA<AuthenticationEvent>(),
      );

      expect(tLogoutOnlineRequested.props[0], tUsername);
      expect(tLogoutOnlineRequested.props[1], tAccessKey);

      expect(
        tLogoutOnlineRequested,
        CheckAuthenticationRequested(
          username: tUsername,
          accesskey: tAccessKey,
        ),
      );
    });

    test(
        'Should event be AuthenticationEventTest when '
        'call LogoutOfflineRequested constructor', () {
      //Arrange
      final tUsername = 'teste@senior.com.br';

      //Act
      var tLogoutOfflineRequested = LogoutOfflineRequested(username: tUsername);

      //Assert
      expect(
        tLogoutOfflineRequested,
        isA<AuthenticationEvent>(),
      );

      expect(tLogoutOfflineRequested.props[0], tUsername);
      expect(tLogoutOfflineRequested.props[1], false);

      expect(
        tLogoutOfflineRequested,
        LogoutOfflineRequested(username: tUsername),
      );
    });

    test(
        'Should event be AuthenticationEventTest when '
        'call LogoutOfflineRequested constructor', () {
      //Arrange

      //Act
      var tCheckBiometricAuthenticationRequested =
          CheckBiometricAuthenticationRequested(
        biometricMessage: 'biometricMessage',
      );

      //Assert
      expect(
        tCheckBiometricAuthenticationRequested,
        isA<AuthenticationEvent>(),
      );

      expect(
        tCheckBiometricAuthenticationRequested,
        CheckBiometricAuthenticationRequested(
          biometricMessage: 'biometricMessage',
        ),
      );
    });

    test(
        'Should event be AuthenticationEventTest when '
        'call LogoutOfflineRequested constructor', () {
      //Act
      var tCheckBiometricAuthenticationRequested =
          AuthenticationBiometricAuthRequested(
        biometricMessage: 'biometricMessage',
        biometricEnabled: true,
        status: AuthenticationStatus.authenticated,
      );

      //Assert
      expect(
        tCheckBiometricAuthenticationRequested,
        isA<AuthenticationEvent>(),
      );

      expect(
        tCheckBiometricAuthenticationRequested,
        AuthenticationBiometricAuthRequested(
          biometricMessage: 'biometricMessage',
          biometricEnabled: true,
          status: AuthenticationStatus.authenticated,
        ),
      );
    });

    test(
        'Should event be AuthenticationEventTest when '
        'call AuthenticateKey constructor', () {
      //Arrange
      //Act
      var tAuthenticateKey = const AuthenticateKey(tAccessKey);

      //Assert
      expect(
        tAuthenticateKey,
        isA<AuthenticationEvent>(),
      );

      expect(tAuthenticateKey.props[0], tAccessKey);
      expect(tAuthenticateKey, const AuthenticateKey(tAccessKey));
    });
  });
}
