// ignore_for_file: prefer_const_constructors

import 'package:flutter_test/flutter_test.dart';
import 'package:senior_platform_authentication_ui/senior_platform_authentication_ui.dart';

void main() {
  const tUsername = 'teste@senior.com.br';
  const tAccessKey = 'accessKey';

  group('AuthenticationStateTest', () {
    test(
        'Should return AuthenticationState when '
        'call AuthenticationState.unknown constructor', () {
      // Arrange
      final tUnknownState = AuthenticationState.unknown();

      // Asserts
      expect(tUnknownState, isA<AuthenticationState>());
    });

    test(
        'Should return AuthenticationState when '
        'call AuthenticationState.authenticated constructor', () {
      // Arrange
      final tUnknownState = AuthenticationState.authenticated();

      // Asserts
      expect(tUnknownState, isA<AuthenticationState>());
    });

    test(
        'Should return AuthenticationState with username when '
        'call AuthenticationState.authenticated constructor with username', () {
      // Arrange
      final tUnknownState =
          AuthenticationState.authenticated(username: tUsername);

      // Asserts
      expect(tUnknownState, isA<AuthenticationState>());
      expect(tUnknownState.username, tUsername);
    });

    test(
        'Should return AuthenticationState when '
        'call AuthenticationState.unauthenticated constructor', () {
      // Arrange
      final tUnknownState = AuthenticationState.unauthenticated();

      // Asserts
      expect(tUnknownState, isA<AuthenticationState>());
    });

    test(
        'Should return AuthenticationState when '
        'call AuthenticationState.offline constructor', () {
      // Arrange
      final tUnknownState = AuthenticationState.offline(tUsername);

      // Asserts
      expect(tUnknownState, isA<AuthenticationState>());
    });

    test(
        'Should return AuthenticationState when '
        'call AuthenticationState.keyAuthenticated constructor', () {
      // Arrange
      final tkeyAuthenticatedState = AuthenticationState.keyAuthenticated(
        accessKey: tAccessKey,
      );

      // Asserts
      expect(tkeyAuthenticatedState.accessKey, tAccessKey);
      expect(
        tkeyAuthenticatedState.accessKeyStatus,
        AuthenticationStatus.authenticated,
      );
      expect(tkeyAuthenticatedState, isA<AuthenticationState>());
    });

    test(
        'Should return AuthenticationState when '
        'call AuthenticationState.keyUnauthenticated constructor', () {
      // Arrange
      final tkeyAuthenticatedState = AuthenticationState.keyUnauthenticated();

      // Asserts
      expect(tkeyAuthenticatedState.accessKey, null);
      expect(
        tkeyAuthenticatedState.accessKeyStatus,
        AuthenticationStatus.unauthenticated,
      );
      expect(tkeyAuthenticatedState, isA<AuthenticationState>());
    });

    test(
        'Should return AuthenticationState when '
        'call AuthenticationState.keyOffline constructor', () {
      // Arrange
      final tkeyAuthenticatedState = AuthenticationState.keyOffline(tAccessKey);

      // Asserts
      expect(tkeyAuthenticatedState.accessKey, tAccessKey);
      expect(
        tkeyAuthenticatedState.accessKeyStatus,
        AuthenticationStatus.offline,
      );
      expect(tkeyAuthenticatedState, isA<AuthenticationState>());
    });
  });
}
