import 'package:flutter_test/flutter_test.dart';
import 'package:mocktail/mocktail.dart';
import 'package:senior_platform_authentication_ui/src/core/utils/biometric_auth/data/repositories/biometric_repository.dart';
import 'package:senior_platform_authentication_ui/src/core/utils/biometric_auth/domain/usecases/biometric_authenticate_usecase.dart';
import 'package:senior_platform_authentication_ui/src/core/utils/constants.dart';

class MockBiometricAuthRepository extends Mock implements BiometricRepository {}

void main() {
  group('BiometricAuthAuthenticateUseCase', () {
    late BiometricAuthenticateUsecase useCase;
    late BiometricRepository repository;

    setUp(() {
      repository = MockBiometricAuthRepository();
      useCase = BiometricAuthenticateUsecase(repository: repository);
    });

    test('authenticate should call authenticate on the repository', () async {
      // Arrange
      when(() => repository.biometricsAuthenticate(
            localizedReason: "localizedReason",
          )).thenAnswer((_) async => BiometryStatus.success);

      // Act
      final result = await useCase.call("localizedReason");

      // Assert
      verify(() => repository.biometricsAuthenticate(
            localizedReason: "localizedReason",
          )).called(1);
      expect(result, BiometryStatus.success);
    });
  });
}
