import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:network_image_mock/network_image_mock.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_platform_authentication_ui/src/core/l10n/l10n_extension.dart';
import 'package:senior_platform_authentication_ui/src/core/widgets/base_authentication_screen.dart';
import 'package:senior_platform_authentication_ui/src/presentation/helper_screen/helper_screen.dart';

void main() {
  Widget makeTestableWidget() {
    return SeniorDesignSystem(
      child: BaseAuthenticationScreen(
        child: SeniorBackdrop(
            title: Builder(
              builder: (context) => Text(
                context.l10n.help,
              ),
            ),
            body: const HelperScreen(
              isLoginHelp: true,
            )),
      ),
    );
  }

  Widget makeTestableWidgetWhithelpImageUrl() {
    return SeniorDesignSystem(
      child: BaseAuthenticationScreen(
        child: SeniorBackdrop(
          title: Builder(
            builder: (context) => Text(
              context.l10n.help,
            ),
          ),
          body: const HelperScreen(
              isMfaHelp: true,
              helpImageUrl:
                  'https://cdn-icons-png.flaticon.com/512/682/682055.png'),
        ),
      ),
    );
  }

  Widget makeTestableWidgetWhithelploginImageUrl() {
    return SeniorDesignSystem(
      child: BaseAuthenticationScreen(
        child: SeniorBackdrop(
          title: Builder(
            builder: (context) => Text(
              context.l10n.help,
            ),
          ),
          body: const HelperScreen(
              isLoginHelp: true,
              loginImageUrl:
                  'https://cdn-icons-png.flaticon.com/512/682/682055.png'),
        ),
      ),
    );
  }

  testWidgets('helper screen No image test...', (tester) async {
    await tester.pumpWidget(makeTestableWidget());

    final loginHelperWidget = find.byType(Text);

    expect(loginHelperWidget, findsAtLeastNWidgets(9));
  });

  testWidgets('helper screen whit loginImageUrl when it is  isMfaHelp test...',
      (tester) async {
    await mockNetworkImagesFor(
        () => tester.pumpWidget(makeTestableWidgetWhithelpImageUrl()));

    await tester.pump(const Duration(seconds: 10));

    final loginHelperWidget = find.byType(Text);

    final image = find.byType(Image);

    expect(loginHelperWidget, findsAtLeastNWidgets(9));
    expect(image, findsOneWidget);
  });

  testWidgets('helper screen whit oginImageUrl when it is  isLoginHelp test...',
      (tester) async {
    await mockNetworkImagesFor(
      () => tester.pumpWidget(
        makeTestableWidgetWhithelploginImageUrl(),
      ),
    );

    await tester.pump(const Duration(seconds: 10));

    final loginHelperWidget = find.byType(Text);

    final image = find.byType(Image);

    expect(loginHelperWidget, findsAtLeastNWidgets(9));
    expect(image, findsOneWidget);
  });
}
